"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var chai_1 = require("chai");
var path = require("path");
var getFileDocumentation_1 = require("../getFileDocumentation");
describe('getFileDocumentation', function () {
    it('Should parse class-based components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Column.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal(c.name, 'Column');
        chai_1.assert.equal(c.comment, 'Form column.');
        chai_1.assert.equal(c.extends, 'Component');
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal(i.name, 'IColumnProps');
        chai_1.assert.equal(i.comment, 'Column properties.');
        chai_1.assert.equal(i.members.length, 4);
        chai_1.assert.equal(i.members[0].name, 'prop1');
        chai_1.assert.equal(i.members[0].comment, 'prop1 description');
        chai_1.assert.equal(i.members[0].isRequired, false);
        chai_1.assert.equal(i.members[1].name, 'prop2');
        chai_1.assert.equal(i.members[1].comment, 'prop2 description');
        chai_1.assert.equal(i.members[1].isRequired, true);
        chai_1.assert.equal(i.members[2].name, 'prop3');
        chai_1.assert.equal(i.members[2].comment, 'prop3 description');
        chai_1.assert.equal(i.members[2].isRequired, true);
        chai_1.assert.equal(i.members[3].name, 'prop4');
        chai_1.assert.equal(i.members[3].comment, 'prop4 description');
        chai_1.assert.equal(i.members[3].isRequired, true);
    });
    it('Should parse class-based components (2)', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/AppMenu.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal(c.name, 'AppMenu');
        chai_1.assert.equal(c.comment, 'App Menu Component');
        chai_1.assert.equal(c.extends, 'Component');
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal(i.name, 'IAppMenuProps');
        chai_1.assert.equal(i.comment, 'App Menu Props');
        chai_1.assert.equal(1, i.members.length);
        chai_1.assert.equal(i.members[0].name, 'menu');
        chai_1.assert.equal(i.members[0].comment, 'Menu items');
    });
    it('Should parse class-based components with unexported props interface', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ColumnWithoutExportedProps.tsx'); // it's running in ./temp    
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal(c.name, 'Column');
        chai_1.assert.equal(c.comment, 'Form column.');
        chai_1.assert.equal(c.extends, 'Component');
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal(i.name, 'IColumnProps');
        chai_1.assert.equal(i.comment, 'Column properties.');
        chai_1.assert.equal(4, i.members.length);
        chai_1.assert.equal(i.members[0].name, 'prop1');
        chai_1.assert.equal(i.members[0].comment, 'prop1 description');
        chai_1.assert.equal(i.members[0].isRequired, false);
        chai_1.assert.equal(i.members[1].name, 'prop2');
        chai_1.assert.equal(i.members[1].comment, 'prop2 description');
        chai_1.assert.equal(i.members[1].isRequired, true);
        chai_1.assert.equal(i.members[2].name, 'prop3');
        chai_1.assert.equal(i.members[2].comment, 'prop3 description');
        chai_1.assert.equal(i.members[2].isRequired, true);
        chai_1.assert.equal(i.members[3].name, 'prop4');
        chai_1.assert.equal(i.members[3].comment, 'prop4 description');
        chai_1.assert.equal(i.members[3].isRequired, true);
    });
    it('Should parse functional components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Row.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal(c.name, 'Row');
        chai_1.assert.equal(c.comment, 'Form row.');
        chai_1.assert.equal(c.extends, 'StatelessComponent');
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal(i.name, 'IRowProps');
        chai_1.assert.equal(i.comment, 'Row properties.');
        chai_1.assert.equal(i.members.length, 4);
        chai_1.assert.equal(i.members[0].name, 'prop1');
        chai_1.assert.equal(i.members[0].comment, 'prop1 description');
        chai_1.assert.equal(i.members[0].isRequired, false);
        chai_1.assert.equal(i.members[1].name, 'prop2');
        chai_1.assert.equal(i.members[1].comment, 'prop2 description');
        chai_1.assert.equal(i.members[1].isRequired, true);
        chai_1.assert.equal(i.members[2].name, 'prop3');
        chai_1.assert.equal(i.members[2].comment, 'prop3 description');
        chai_1.assert.equal(i.members[2].isRequired, true);
        chai_1.assert.equal(i.members[3].name, 'prop4');
        chai_1.assert.equal(i.members[3].comment, 'prop4 description');
        chai_1.assert.equal(i.members[3].isRequired, true);
    });
    it('Should parse class-based pure components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/PureRow.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(result.components.length, 1);
        var c = result.components[0];
        chai_1.assert.equal(c.name, 'Row');
        chai_1.assert.equal(c.comment, 'Form row.');
        chai_1.assert.equal(c.extends, 'PureComponent');
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal(i.name, 'IRowProps');
        chai_1.assert.equal(i.comment, 'Row properties.');
        chai_1.assert.equal(i.members.length, 4);
        chai_1.assert.equal(i.members[0].name, 'prop1');
        chai_1.assert.equal(i.members[0].comment, 'prop1 description');
        chai_1.assert.equal(i.members[0].isRequired, false);
        chai_1.assert.equal(i.members[1].name, 'prop2');
        chai_1.assert.equal(i.members[1].comment, 'prop2 description');
        chai_1.assert.equal(i.members[1].isRequired, true);
        chai_1.assert.equal(i.members[2].name, 'prop3');
        chai_1.assert.equal(i.members[2].comment, 'prop3 description');
        chai_1.assert.equal(i.members[2].isRequired, true);
        chai_1.assert.equal(i.members[3].name, 'prop4');
        chai_1.assert.equal(i.members[3].comment, 'prop4 description');
        chai_1.assert.equal(i.members[3].isRequired, true);
    });
    it('Should avoid parsing exported objects as components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ConstExport.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(result.components.length, 1);
        var c = result.components[0];
        chai_1.assert.equal(c.name, 'Row');
        chai_1.assert.equal(c.comment, 'Form row.');
        chai_1.assert.equal(c.extends, 'StatelessComponent');
        chai_1.assert.isNotNull(c);
        var i = c.propInterface;
        chai_1.assert.equal(i.name, 'IRowProps');
        chai_1.assert.equal(i.comment, 'Row properties.');
        chai_1.assert.equal(i.members.length, 4);
        chai_1.assert.equal(i.members[0].name, 'prop1');
        chai_1.assert.equal(i.members[0].comment, 'prop1 description');
        chai_1.assert.equal(i.members[0].isRequired, false);
        chai_1.assert.equal(i.members[1].name, 'prop2');
        chai_1.assert.equal(i.members[1].comment, 'prop2 description');
        chai_1.assert.equal(i.members[1].isRequired, true);
        chai_1.assert.equal(i.members[2].name, 'prop3');
        chai_1.assert.equal(i.members[2].comment, 'prop3 description');
        chai_1.assert.equal(i.members[2].isRequired, true);
        chai_1.assert.equal(i.members[3].name, 'prop4');
        chai_1.assert.equal(i.members[3].comment, 'prop4 description');
        chai_1.assert.equal(i.members[3].isRequired, true);
    });
    it('Should parse higher order components', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ColumnHigherOrderComponent.tsx'); // it's running in ./temp        
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(result.components.length, 6);
        var r1 = result.components[0];
        chai_1.assert.equal(r1.name, 'ColumnHigherOrderComponent1');
        chai_1.assert.equal(r1.comment, 'ColumnHigherOrderComponent1 specific comment');
        chai_1.assert.equal(r1.extends, 'Column');
        chai_1.assert.isNotNull(r1.propInterface);
        var p1 = r1.propInterface;
        chai_1.assert.equal(p1.name, 'IColumnProps');
        chai_1.assert.equal(p1.comment, 'Column properties.');
        chai_1.assert.equal(p1.members.length, 4);
        chai_1.assert.equal(p1.members[0].name, 'prop1');
        chai_1.assert.equal(p1.members[0].comment, 'prop1 description');
        chai_1.assert.equal(p1.members[0].isRequired, false);
        chai_1.assert.equal(p1.members[1].name, 'prop2');
        chai_1.assert.equal(p1.members[1].comment, 'prop2 description');
        chai_1.assert.equal(p1.members[1].isRequired, true);
        chai_1.assert.equal(p1.members[2].name, 'prop3');
        chai_1.assert.equal(p1.members[2].comment, 'prop3 description');
        chai_1.assert.equal(p1.members[2].isRequired, true);
        chai_1.assert.equal(p1.members[3].name, 'prop4');
        chai_1.assert.equal(p1.members[3].comment, 'prop4 description');
        chai_1.assert.equal(p1.members[3].isRequired, true);
        var r2 = result.components[1];
        chai_1.assert.equal(r2.name, 'ColumnHigherOrderComponent2');
        chai_1.assert.equal(r2.comment, 'Form column.');
        chai_1.assert.equal(r2.extends, 'Column');
        chai_1.assert.isNotNull(r2.propInterface);
        var p2 = r2.propInterface;
        chai_1.assert.equal(p2.name, 'IColumnProps');
        var r3 = result.components[2];
        chai_1.assert.equal(r3.name, 'ColumnExternalHigherOrderComponent');
        chai_1.assert.equal(r3.comment, 'Form column.');
        chai_1.assert.equal(r3.extends, 'Column');
        chai_1.assert.isNotNull(r3.propInterface);
        var p3 = r3.propInterface;
        chai_1.assert.equal(p3.name, 'IColumnProps');
        var r4 = result.components[3];
        chai_1.assert.equal(r4.name, 'RowHigherOrderComponent1');
        chai_1.assert.equal(r4.comment, 'RowHigherOrderComponent1 specific comment');
        chai_1.assert.equal(r4.extends, 'Row');
        chai_1.assert.isNotNull(r4.propInterface);
        var p4 = r4.propInterface;
        chai_1.assert.equal(p4.name, 'IRowProps');
        var r5 = result.components[4];
        chai_1.assert.equal(r5.name, 'RowHigherOrderComponent2');
        chai_1.assert.equal(r5.comment, 'Form row.');
        chai_1.assert.equal(r5.extends, 'Row');
        chai_1.assert.isNotNull(r5.propInterface);
        var p5 = r5.propInterface;
        chai_1.assert.equal(p5.name, 'IRowProps');
        var r6 = result.components[5];
        chai_1.assert.equal(r6.name, 'RowExternalHigherOrderComponent');
        chai_1.assert.equal(r6.comment, 'Form row.');
        chai_1.assert.equal(r6.extends, 'Row');
        chai_1.assert.isNotNull(r6.propInterface);
        var p6 = r6.propInterface;
        chai_1.assert.equal(p6.name, 'IRowProps');
    });
    it('Should accept type as props', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/FlippableImage.tsx'); // it's running in ./temp        
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var r1 = result.components[0];
        chai_1.assert.equal(r1.name, 'FlippableImage');
        chai_1.assert.isNotNull(r1.propInterface);
        var p1 = r1.propInterface;
        chai_1.assert.equal(p1.name, 'Props');
        chai_1.assert.equal(p1.comment, 'Props comment ');
        chai_1.assert.equal(p1.members.length, 2);
        chai_1.assert.equal(p1.members[0].name, 'isFlippedX');
        chai_1.assert.equal(p1.members[0].comment, 'whether the image is flipped horizontally');
        chai_1.assert.equal(p1.members[1].name, 'isFlippedY');
        chai_1.assert.equal(p1.members[1].comment, 'whether the image is flipped vertically');
    });
    it('Should recognize props defined in different file', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/ExternalPropsComponent.tsx'); // it's running in ./temp        
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var r1 = result.components[0];
        chai_1.assert.equal(r1.name, 'ExternalPropsComponent');
        chai_1.assert.isNotNull(r1.propInterface);
        var p1 = r1.propInterface;
        chai_1.assert.equal(p1.name, 'ExternalPropsComponentProps');
        // assert.equal(p1.comment, 'ExternalPropsComponentProps props');
    });
    it('Should parse file that worked in v0.0.11', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/Regression_v0_0_12.tsx'); // it's running in ./temp        
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
    });
    it('Should parse inline function ', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/InlineConst.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('MyComponent', c.name);
        chai_1.assert.equal('My InlineConst Component', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IReproProps', i.name);
        chai_1.assert.equal('A repro props interface', i.comment);
        chai_1.assert.equal(1, i.members.length);
        chai_1.assert.equal('foo', i.members[0].name);
        chai_1.assert.equal('A foo property', i.members[0].comment);
    });
    it('Should parse component with unassigned let', function () {
        var fileName = path.join(__dirname, '../../src/__tests__/data/UnassignedLet.tsx'); // it's running in ./temp
        var result = getFileDocumentation_1.getFileDocumentation(fileName);
        chai_1.assert.ok(result.components);
        chai_1.assert.equal(1, result.components.length);
        var c = result.components[0];
        chai_1.assert.equal('Repro', c.name);
        chai_1.assert.equal('My Repro Component', c.comment);
        chai_1.assert.equal('Component', c.extends);
        chai_1.assert.isNotNull(c.propInterface);
        var i = c.propInterface;
        chai_1.assert.equal('IReproProps', i.name);
        chai_1.assert.equal('A repro props interface', i.comment);
        chai_1.assert.equal(1, i.members.length);
        chai_1.assert.equal('foo', i.members[0].name);
        chai_1.assert.equal('A foo property', i.members[0].comment);
    });
});
//# sourceMappingURL=getFileDocumentation.spec.js.map